@@ -24,7 +24,7 @@ fn front_back() {
 
 
 #[test]
-fn push_front() {
+fn push() {
     let mut list = DoublyLinkedList::new();
 
     list.push_front(1);
@@ -33,11 +33,7 @@ fn push_front() {
     assert_eq!(list.len(), 2);
     assert_eq!(list.front(), Some(&2));
     assert_eq!(list.back(), Some(&1));
-}
 
-
-#[test]
-fn push_back() {
     let mut list = DoublyLinkedList::new();
 
     list.push_back(1);
@@ -46,4 +42,17 @@ fn push_back() {
     assert_eq!(list.len(), 2);
     assert_eq!(list.front(), Some(&1));
     assert_eq!(list.back(), Some(&2));
+}
+
+
+#[test]
+fn get() {
+    let mut list = dl_list![1, 2, 3];
+
+    assert_eq!(list.get_mut(0), Some(&mut 1));
+    assert_eq!(list.get_mut(1), Some(&mut 2));
+    assert_eq!(list.get_mut(2), Some(&mut 3));
+    assert_eq!(list.get(0), Some(&1));
+    assert_eq!(list.get(1), Some(&2));
+    assert_eq!(list.get(2), Some(&3));
 }
\ No newline at end of file
